//
//  tank
//
//  Import and Playlist Daemon for autoradio project
//
//
//  Copyright (C) 2017 Christian Pointner <equinox@helsinki.at>
//
//  This file is part of tank.
//
//  tank is free software: you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation, either version 3 of the License, or
//  any later version.
//
//  tank is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with tank. If not, see <http://www.gnu.org/licenses/>.
//

package main

import (
	"fmt"
	"net/http"

	"github.com/gorilla/mux"
)

func webAPIv1_Index(w http.ResponseWriter, r *http.Request) {
	fmt.Fprintf(w, "welcome to /api/v1")
	// TODO: print endpioint listing
}

func webAPIv1_Groups_List(w http.ResponseWriter, r *http.Request) {
	http.Error(w, "listing groups not yet implemented", http.StatusNotImplemented)
}

func webAPIv1_PlaylistsOfGroup_List(w http.ResponseWriter, r *http.Request) {
	http.Error(w, "listing playlists of group not yet implemented", http.StatusNotImplemented)
}

func webAPIv1_PlaylistsOfGroup_Create(w http.ResponseWriter, r *http.Request) {
	http.Error(w, "creating playlists in group not yet implemented", http.StatusNotImplemented)
}

func webAPIv1_PlaylistsOfGroup_Read(w http.ResponseWriter, r *http.Request) {
	http.Error(w, "reading playlist of group not yet implemented", http.StatusNotImplemented)
}

func webAPIv1_PlaylistsOfGroup_Update(w http.ResponseWriter, r *http.Request) {
	http.Error(w, "updateing playlist of group not yet implemented", http.StatusNotImplemented)
}

func webAPIv1_PlaylistsOfGroup_Delete(w http.ResponseWriter, r *http.Request) {
	http.Error(w, "deleting playlist from group not yet implemented", http.StatusNotImplemented)
}

func webAPIv1_FilesOfGroup_List(w http.ResponseWriter, r *http.Request) {
	http.Error(w, "listing files of group not yet implemented", http.StatusNotImplemented)
}

func webAPIv1_FilesOfGroup_Create(w http.ResponseWriter, r *http.Request) {
	http.Error(w, "create files in group not yet implemented", http.StatusNotImplemented)
}

func webAPIv1_FilesOfGroup_Read(w http.ResponseWriter, r *http.Request) {
	http.Error(w, "reading file of group not yet implemented", http.StatusNotImplemented)
}

func webAPIv1_FilesOfGroup_Update(w http.ResponseWriter, r *http.Request) {
	http.Error(w, "updateing file of group not yet implemented", http.StatusNotImplemented)
}

func webAPIv1_FilesOfGroup_Delete(w http.ResponseWriter, r *http.Request) {
	http.Error(w, "deleting file from group not yet implemented", http.StatusNotImplemented)
}

func webAPIv1__methodNotAllowed(w http.ResponseWriter, r *http.Request) {
	http.Error(w, "method not allowed", http.StatusMethodNotAllowed)
}

func webAPIv1InstallHandler(r *mux.Router) {
	r.HandleFunc("", webAPIv1_Index)
	r.HandleFunc("/", webAPIv1_Index)

	r.HandleFunc("/groups", webAPIv1_Groups_List)

	r.HandleFunc("/groups/{group-id}/playlists", webAPIv1_PlaylistsOfGroup_List).Methods("GET")
	r.HandleFunc("/groups/{group-id}/playlists", webAPIv1_PlaylistsOfGroup_Create).Methods("POST")
	r.HandleFunc("/groups/{group-id}/playlists", webAPIv1__methodNotAllowed)
	r.HandleFunc("/groups/{group-id}/playlists/{playlist-id}", webAPIv1_PlaylistsOfGroup_Read).Methods("GET")
	r.HandleFunc("/groups/{group-id}/playlists/{playlist-id}", webAPIv1_PlaylistsOfGroup_Update).Methods("PUT")
	r.HandleFunc("/groups/{group-id}/playlists/{playlist-id}", webAPIv1_PlaylistsOfGroup_Delete).Methods("DELETE")
	r.HandleFunc("/groups/{group-id}/playlists/{playlist-id}", webAPIv1__methodNotAllowed)

	r.HandleFunc("/groups/{group-id}/files", webAPIv1_FilesOfGroup_List).Methods("GET")
	r.HandleFunc("/groups/{group-id}/files", webAPIv1_FilesOfGroup_Create).Methods("POST")
	r.HandleFunc("/groups/{group-id}/files", webAPIv1__methodNotAllowed)
	r.HandleFunc("/groups/{group-id}/files/{file-id}", webAPIv1_FilesOfGroup_Read).Methods("GET")
	r.HandleFunc("/groups/{group-id}/files/{file-id}", webAPIv1_FilesOfGroup_Update).Methods("PUT")
	r.HandleFunc("/groups/{group-id}/files/{file-id}", webAPIv1_FilesOfGroup_Delete).Methods("DELETE")
	r.HandleFunc("/groups/{group-id}/files/{file-id}", webAPIv1__methodNotAllowed)
}
